@@ -5,14 +5,19 @@ import threading
 import time, sys, math
 
 parts = '▁ ▂ ▃ ▄ ▅ ▆ ▅ ▄ ▃ ▁'.split(' ')
+parts = [ '▁' ] * len(parts) + parts
 frames = [
-  ' '.join(parts[offset:] + parts[:offset])
+  ' '.join((parts[offset:] + parts[:offset])[:int(len(parts) / 2)])
   for offset in reversed(range(len(parts)))
 ]
 
 class Spinner:
 
-    def __init__(self):
+    def __init__(self, show_timer=False, delay=0):
+        self.show_timer = show_timer
+        self.delay = delay
+        self.running = False
+
         self.__screen_lock = threading.Event()
         self.__spinner = cycle(frames)
         self.__stop_event = False
@@ -20,17 +25,25 @@ class Spinner:
 
     def __enter__(self):
       self.start()
+      return self
 
     def __exit__(self, *args):
       self.stop()
 
     def start(self):
+        self.running = True
         start_time = time.time()
         self.__stop_event = False
 
         def run_spinner():
             while not self.__stop_event:
-                print(f"\r[ {math.floor(time.time() - start_time)}s ] {next(self.__spinner)}  ", end="")
+                time_diff = time.time() - start_time
+                if time_diff > self.delay:
+                    frame = next(self.__spinner)
+                    if self.show_timer:
+                        print(f"\r[ {math.floor(time_diff)}s ] {frame}  ", end="")
+                    else:
+                        print(f"\r{frame}  ", end="")
                 time.sleep(0.05)
 
             self.__screen_lock.set()
@@ -39,6 +52,8 @@ class Spinner:
         self.__thread.start()
 
     def stop(self):
+        if not self.running:
+            return
         self.__stop_event = True
         if self.__screen_lock.is_set():
             self.__screen_lock.wait()
